@@ -4,6 +4,8 @@ BasicConfig, MainConfig, MainSettings, UrlsConfig, moneta_config
 
 from .url_generator import (UrlGenerator, QueryPayload)
 
+from .soap_client import SoapClient
+
 __all__ = [
     "BasicConfig",
     "MainConfig",
@@ -12,6 +14,7 @@ __all__ = [
     "UrlGenerator",
     "QueryPayload",
     "moneta_config",
+    "SoapClient",
 ]
 
 
